Macro impl_fixed_convert_signed

macro_rules! impl_fixed_convert_signed {
    ($($t:ty),* => $fixed:ty) => { ... };
}
Implements IntegerToFixed conversion for all signed integer types in the list.

  • to_fixed: Converts the integer into the corresponding fixed-point type using saturating conversion.
  • from_fixed: Converts back from fixed-point to the integer, clamping to both the integer’s min and max if the fixed-point inner value is out of bounds.

Usage: impl_fixed_convert_signed!(i8, i16, i32 => FixedI64);